/**
 * SQLData class establishes connections to the database server and
 * gets the customer data from NorthWind database that comes with SQL server.
 */
import com.ms.jdbc.odbc.*;
import java.sql.*;
import java.util.*;

public class SQLData
{
	Connection dbCon_ = null;
	
	//Connection string for connecting to local SQL server.
	//It can be changed to point to any other SQL server
	String conInfo_ = "JDBC:ODBC:DRIVER={SQL Server};" +
								"SERVER=(local);DATABASE=northwind;UID=sa;PWD=;";
	
	public SQLData()
	{
	
	}
	
	public void connectToDB() throws Exception
	{
		try
		{
			if(dbCon_ == null)
			{	
				JdbcOdbcDriver jdbcDriver = new JdbcOdbcDriver();
				dbCon_ = DriverManager.getConnection(conInfo_,"","");				
			}	
		}	
		catch(Exception ex)
		{
			throw ex;
		}	
	}
	
	public Hashtable getCountryCompany() throws Exception
	{
		Hashtable countryCompanyMap = new Hashtable();
		Statement stmt = null;
		ResultSet rs = null;		
		try
		{				
			//Form the SQL query that gets the customer data for a given customerID
			String sqlQuery = "Select " +
								"Country," +
								"CompanyName " +
							 "From Customers";				
			stmt = dbCon_.createStatement();	
			rs = stmt.executeQuery(sqlQuery);
			while(rs.next())
			{
				String countryId = rs.getString("Country");
				if(countryCompanyMap.containsKey(countryId))
				{
					Vector companyList = (Vector)countryCompanyMap.get(countryId);
					companyList.addElement(rs.getString("CompanyName"));
				}
				else
				{
					Vector companyList = new Vector();
					companyList.addElement(rs.getString("CompanyName"));
					countryCompanyMap.put(countryId,companyList);
				}	
				   
			}
			return countryCompanyMap;
		}
		catch(Exception ex)
		{
			throw ex;
		}
		finally
		{
			if(rs != null)
				rs.close();
			
			if(stmt != null)
				stmt.close();
		}	
	}	
	
	public String[] getCustomerData(String companyName) throws Exception
	{
		String customerData[] = {"","","",""};
		
		Statement stmt = null;
		ResultSet rs = null;		
		try
		{				
			//Form the SQL query that gets the customer data for a given customerID
			String sqlQuery = "Select " +
								"ContactTitle," +
								"ContactName," +
								"Phone,"+
							    "Address " +
							 "From Customers " +
							 "Where " +
								"CompanyName = '" + escapeSQL(companyName) + "'";
				
			stmt = dbCon_.createStatement();	
			rs = stmt.executeQuery(sqlQuery);
			if(rs.next())
			{
				customerData[0] = rs.getString("ContactTitle");
				customerData[1] = rs.getString("ContactName");
				customerData[2] = rs.getString("Phone");
				customerData[3] = rs.getString("Address");
				
			}
			return customerData;
		}
		catch(Exception ex)
		{
			throw ex;
		}
		finally
		{
			if(rs != null)
				rs.close();
			
			if(stmt != null)
				stmt.close();
		}
	}
	
	private String escapeSQL(String sqlParam)
	{
		if(sqlParam.indexOf("'") != -1)
		{	
			StringBuffer escapedSQLParam = new StringBuffer();
			char []sqlParamArray = sqlParam.toCharArray();
			for(int i = 0; i < sqlParamArray.length; i++)
			{
				if(sqlParamArray[i] == '\'')
					escapedSQLParam.append("''");	
				else
					escapedSQLParam.append(sqlParamArray[i]);
			}
			
			return escapedSQLParam.toString();
		}
		else
		{
			return sqlParam;	
		}		
	}	
	
	public void closeDBConnection() throws Exception
	{
		try
		{
			if(dbCon_ != null)
				dbCon_.close();
		}
		catch(Exception ex)
		{
			throw ex;
		}
	}
}
