/**
 * ViewCustomer shows the customer data for a given customer Id. It gets the data
 * using SQLData class.
 */

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.ui.*;
import com.ms.wfc.html.*;
import java.util.*;

/**
 * This class can take a variable number of parameters on the command
 * line. Program execution begins with the main() method. The class
 * constructor is not invoked unless an object of type 'ViewCustomer'
 * created in the main() method.
 */
public class ViewCustomer extends Form
{
	SQLData sqlData_ = new SQLData();
	
	public ViewCustomer()
	{
		super();

		// Required for Visual J++ Form Designer support
		initForm();
		
		try
		{
			sqlData_.connectToDB();
			populateCustomerTree();
		}
		catch(Exception ex)
		{
		
		}		
	}
	
	private void populateCustomerTree() throws Exception
	{
		TreeNode rootNode = this.tvCustomer.addNode("Countries");
		
		Hashtable htCountryCompanyMap = sqlData_.getCountryCompany();
		Enumeration countryEnum = htCountryCompanyMap.keys();
		while(countryEnum.hasMoreElements())
		{
			String countryId = (String)countryEnum.nextElement();
			TreeNode countryNode = rootNode.addNode(countryId);
			Vector companyList = (Vector)htCountryCompanyMap.get(countryId);
			for(int k = 0; k < companyList.size(); k++)
			{
				String comapnyName = (String)companyList.elementAt(k);
				countryNode.addNode(comapnyName);
			}
		}	
	}

	/**
	 * ViewCustomer overrides dispose so it can clean up the
	 * component list.
	 */
	public void dispose()
	{
		super.dispose();
		components.dispose();
	}

	private void btnOK_click(Object source, Event e)
	{
		close();
	}

	private void ViewCustomer_closed(Object source, Event e)
	{
		try
		{
			sqlData_.closeDBConnection();
		}
		catch(Exception ex)
		{		
		}	
	}

	private void tvCustomer_afterSelect(Object source, TreeViewEvent e)
	{
		TreeNode currentNode = e.node;
		if(currentNode.getParent() != null && currentNode.getParent().getParent() != null)
		{	
			String companyName = currentNode.getText();
			try{
				String []customerData = sqlData_.getCustomerData(companyName);			
			
				lbCustomerPath.setText(currentNode.getParent().getText() + "\\" + companyName);
				edContactTitle.setText(customerData[0]);
				edContactName.setText(customerData[1]);
				edPhone.setText(customerData[2]);
				edAddress.setText(customerData[3]);
			}
			catch(Exception ex)
			{ }	
		}	
	}

	/**
	 * NOTE: The following code is required by the Visual J++ form
	 * designer.  It can be modified using the form editor.  Do not
	 * modify it using the code editor.
	 */
	Container components = new Container();
	Label lbAddress = new Label();
	Label lbPhone = new Label();
	Label lbContactTitle = new Label();
	Panel pnlRight = new Panel();
	Label lbContactName = new Label();
	TreeView tvCustomer = new TreeView();
	Splitter spTvCustomer = new Splitter();
	Edit edContactTitle = new Edit();
	Edit edContactName = new Edit();
	Edit edPhone = new Edit();
	Edit edAddress = new Edit();
	Label lbCustomerPath = new Label();

	private void initForm()
	{
		// NOTE:  This form is storing resource information in an
		// external file.  Do not modify the string parameter to any
		// resources.getObject() function call. For example, do not
		// modify "foo1_location" in the following line of code
		// even if the name of the Foo object changes: 
		//   foo1.setLocation((Point)resources.getObject("foo1_location"));

		IResourceManager resources = new ResourceManager(this, "ViewCustomer");
		this.setText("ViewCustomer");
		this.setAutoScaleBaseSize(new Point(5, 13));
		this.setBorderStyle(FormBorderStyle.FIXED_3D);
		this.setClientSize(new Point(530, 363));
		this.setIcon((Icon)resources.getObject("this_icon"));
		this.setMaximizeBox(false);
		this.addOnClosed(new EventHandler(this.ViewCustomer_closed));

		lbAddress.setLocation(new Point(32, 232));
		lbAddress.setSize(new Point(72, 12));
		lbAddress.setTabIndex(3);
		lbAddress.setTabStop(false);
		lbAddress.setText("Address");

		lbPhone.setLocation(new Point(32, 176));
		lbPhone.setSize(new Point(72, 12));
		lbPhone.setTabIndex(2);
		lbPhone.setTabStop(false);
		lbPhone.setText("Phone");

		lbContactTitle.setLocation(new Point(32, 64));
		lbContactTitle.setSize(new Point(64, 12));
		lbContactTitle.setTabIndex(0);
		lbContactTitle.setTabStop(false);
		lbContactTitle.setText("Contact Title");

		pnlRight.setDock(ControlDock.FILL);
		pnlRight.setLocation(new Point(241, 0));
		pnlRight.setSize(new Point(289, 363));
		pnlRight.setTabIndex(2);
		pnlRight.setText("panel1");

		lbContactName.setLocation(new Point(32, 120));
		lbContactName.setSize(new Point(68, 12));
		lbContactName.setTabIndex(1);
		lbContactName.setTabStop(false);
		lbContactName.setText("Contact Name");

		tvCustomer.setDock(ControlDock.LEFT);
		tvCustomer.setSize(new Point(240, 363));
		tvCustomer.setTabIndex(0);
		tvCustomer.setText("treeView1");
		tvCustomer.setIndent(19);
		tvCustomer.setSorted(true);
		tvCustomer.addOnAfterSelect(new TreeViewEventHandler(this.tvCustomer_afterSelect));

		spTvCustomer.setDock(ControlDock.LEFT);
		spTvCustomer.setLocation(new Point(240, 0));
		spTvCustomer.setSize(new Point(1, 363));
		spTvCustomer.setTabIndex(1);
		spTvCustomer.setTabStop(false);

		edContactTitle.setLocation(new Point(32, 80));
		edContactTitle.setSize(new Point(180, 20));
		edContactTitle.setTabIndex(4);
		edContactTitle.setText("");
		edContactTitle.setReadOnly(true);

		edContactName.setLocation(new Point(32, 136));
		edContactName.setSize(new Point(180, 20));
		edContactName.setTabIndex(5);
		edContactName.setText("");
		edContactName.setReadOnly(true);

		edPhone.setLocation(new Point(32, 192));
		edPhone.setSize(new Point(180, 20));
		edPhone.setTabIndex(6);
		edPhone.setText("");
		edPhone.setReadOnly(true);

		edAddress.setLocation(new Point(32, 248));
		edAddress.setSize(new Point(180, 20));
		edAddress.setTabIndex(7);
		edAddress.setText("");
		edAddress.setReadOnly(true);

		lbCustomerPath.setFont(new Font("MS Shell Dlg", 11.0f, FontSize.CHARACTERHEIGHT, FontWeight.BOLD, false, false, false, CharacterSet.DEFAULT, 0));
		lbCustomerPath.setLocation(new Point(32, 24));
		lbCustomerPath.setSize(new Point(232, 24));
		lbCustomerPath.setTabIndex(8);
		lbCustomerPath.setTabStop(false);
		lbCustomerPath.setText("");

		this.setNewControls(new Control[] {
							pnlRight, 
							spTvCustomer, 
							tvCustomer});
		pnlRight.setNewControls(new Control[] {
								lbCustomerPath, 
								edAddress, 
								edPhone, 
								edContactName, 
								edContactTitle, 
								lbAddress, 
								lbPhone, 
								lbContactName, 
								lbContactTitle});
	}

	/**
	 * The main entry point for the application. 
	 *
	 * @param args Array of parameters passed to the application
	 * via the command line.
	 */
	public static void main(String args[])
	{
		Application.run(new ViewCustomer());
	}
}
